# pti-naska
Text-GUI frontend for rsync application.

MIT License

## Installing build dependencies

```
python -m pip install -r -U requirements.txt
```

## Running from command line
```
python3 -m ptinaska.cli --help
```
